pub struct AwsAuthIamPayload {
pub iam_http_request_method: String,
pub iam_request_url: String,
pub iam_request_body: String,
pub iam_request_headers: HashMap<String, Vec<String>>,
}Expand description
Payload for use to generate a payload for AWS IAM authentication
This payload is used by HashiCorp’s Vault and is generated by making a POST request
to AWS STS GetCallerIdentity
See Vault’s Documentation for more information.
Fields
iam_http_request_method: StringHTTP method used in the signed request. Currently only POST is supported
iam_request_url: StringBase64-encoded HTTP URL used in the signed request
iam_request_body: StringBase64-encoded body of the signed request
iam_request_headers: HashMap<String, Vec<String>>Headers of the signed request
Implementations
Sourceimpl AwsAuthIamPayload
impl AwsAuthIamPayload
Sourcepub fn new<R>(
credentials: &AwsCredentials,
region: Option<R>,
additional_headers: HashMap<&str, &str>,
) -> Self
pub fn new<R>( credentials: &AwsCredentials, region: Option<R>, additional_headers: HashMap<&str, &str>, ) -> Self
Creates a payload for use to generate a payload for AWS IAM authentication
This payload is used by HashiCorp’s Vault and is generated by making a POST request
to AWS STS GetCallerIdentity
See Vault’s Documentation
for more information.
If you do not provide a region, we will use a the “global” AWS STS endpoint.